Crate mise_cache_rustc

Crate mise_cache_rustc 

Structs

ActionContext
ActionInput
CompilerIdentity
DepInfoCommand
A side-effect-minimized rustc invocation that emits only dependency data.
DiscoveredInputs
A complete, content-addressed compiler input manifest.
PathMapping
RustcAction
RustcDepInfo
The source and environment inputs reported by rustc’s dep-info output.
RustcInputPrediction
Normalized input names from the last successful execution of one modeled rustc invocation.
RustcInvocation
RustcOutputs
The cacheable files and dependency manifest produced by a rustc invocation.

Enums

BypassReason

Constants

ACTION_SCHEMA_VERSION
ADAPTER_VERSION