pub struct RustcInputPrediction {
pub version: u8,
pub inputs: Vec<String>,
pub environment: Vec<String>,
}Expand description
Normalized input names from the last successful execution of one modeled rustc invocation.
Fields
version: u8inputs: Vec<String>environment: Vec<String>Implementations
Sourceimpl RustcInputPrediction
impl RustcInputPrediction
Sourcepub fn discover(
&self,
working_dir: &Path,
path_mappings: &[PathMapping],
) -> Result<DiscoveredInputs, BypassReason>
pub fn discover( &self, working_dir: &Path, path_mappings: &[PathMapping], ) -> Result<DiscoveredInputs, BypassReason>
Rehash the predicted paths and read the current environment. The caller still recomputes the full action digest, so changed inputs are misses.